#
# spec file for package lxqt-qt5plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
%define _name lxqt-qtplugin

Name:           lxqt-qt5plugin
Version:        1.4.1
Release:        1.4
Summary:        LXQt Qt5 platform integration plugin
License:        LGPL-2.1-or-later
URL:            https://github.com/lxqt/lxqt-qtplugin
Source0:        %{url}/releases/download/%{version}/%{_name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{_name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.18.0
BuildRequires:  gcc-c++
BuildRequires:  libQt5PlatformSupport-private-headers-devel
BuildRequires:  lxqt-build-tools-qt5-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(fm-qt)
BuildRequires:  pkgconfig(Qt5XdgIconLoader)
BuildRequires:  pkgconfig(dbusmenu-qt5)

%description
A library libqtlxqt to integrate Qt5 with LXQt. With this plugin, all
Qt5-based programs can adopt settings of LXQt, such as the icon theme.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install

%check
%ctest

%files
%license LICENSE
%doc AUTHORS CHANGELOG README.md
%{_libdir}/qt5/plugins/platformthemes
%{_libdir}/qt5/plugins/platformthemes/libqtlxqt.so

%changelog
* Mon Jun 10 2024 Shawn Dunn <sfalken@opensuse.org>
- Build 1.4.1 Version (boo#1226151)
  * Required for Qt5 Application Support
* Sat May 11 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6
  * The existence of qApp is checked to prevent crashes.
* Fri Apr 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.4.1:
  * This point release is made because of a backward incompatible
    change in Qt6's font descriptions. It includes a workaround
    which makes Qt5-based apps have correct fonts when fonts are
    set by the Qt6-based LXQt 2.0.0.
* Sun Nov  5 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * Just corrected a case of code readability
  * Bumped the Version
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Bumped the version and update the dependencies
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Bumped the version to 1.2.0 and updated the dependencies.
* Thu Apr 28 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Bumped the version to 1.1.0 and updated the dependencies.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Added workarounds for Qt's poor handling of some dark palettes.
  * Used the C++11 override specifier in some places.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Handled Qt 5.15 deprecations.
  * Don't check before deleting a pointer.
  * Don't use implicit conversions.
  * Fixed a palette/highlight color related typo.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Do not reset widget palettes on changing style.
  * Support more palette colors for better customization.
* Mon Jun  1 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.15.1:
  * Fixed Fusion's window color with Qt 5.15.
  * Made the window color configurable.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-qtplugin.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Set minimum required Qt version to 5.10.0.
  * Added libfm-qt as a dependency (for LXQt file dialog).
  * Added support for flatpak and working without context menu (to status notifier).
  * Removed deprecated QImage methods and updated the code for C++11.
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Dynamically load libfm-qt on demand to create
    the file dialog helper.
  * Don't use automatic string conversions
  * Improved cmake scripting
  - Set cmake_minimum_required to 3.1.0
  - Removed locale compile definitons
  - Removed the superfluous libfm-qt dependency
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * lxqtplatformtheme: Initialize “folowColorScheme” once
  * Fix icon colorizing at startup
  * Remember the view mode
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set an informal patch version
  * Don't export github templates
  * Flag unused vars in onServiceOwnerChanged
  * Fix missing variable declaration
  * Handle QML (as @PCMan suggested)
  * Use mime functions added by @PCMan
  * Loading and saving window/splitter size
  * Central positioning with respect to parent
  * Set window title correctly
  * Qt version conditions
  * Just made it compilable
  * Handle mime-type filters for file dialog. Set custom file dialog labels.
  * Update options properly.
  * Implement a basic file dialog helper using libfm-qt's Fm::FileDialog.
  * Avoid using Qt-specific keywords such as signal/slot and foreach. Instead, use macros.
  * LXQtPlatformTheme: Make Qt use default palette (#22)
  * LXQtPlatformTheme: Add icon FollowColorScheme config (#21)
  * Prevent a possible C++11 range for detach (#20)
  * Use the CMake MODULE library type.
  * LXQtPlatformTheme: Propagate wheelScrollLines
  * LXQtPlatformTheme: Do not provide own palette
  * Fix multiple StatusNotifierItems.
  * Bump year
  * Updates lxqt-build-tools required version
* Sat Mar  4 2017 sfalken@opensuse.org
- Update Source URLs
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Use lxqt-build-tools
  * Use the new lxqt-build-tools package
  * Remove cpack (#14)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Add Qt5XdgIconLoader as dependency (#13)
  * Update README.md
  * statusnotifieritem: Correctly handle menu
  * Cleaned up licenses
  * Use XdgIconLoader library (#10)
  * xdgIconThemePaths: Use QString::SkipEmptyParts
  * xdgIconThemePaths: Remove duplicated paths
  * Adds $XDG_DATA_HOME to the XdgIconThemePaths
  * Bump year in AUTHORS
- Add keyring
- Require pkgconfig(Qt5XdgIconLoader) instead of pkgconfig(Qt5Xdg)
  because IconLoader has its own package now and got split out
  of libqt5xdg.
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
* Mon Jan 26 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora Builds
* Thu Dec 25 2014 hrvoje.senjan@gmail.com
- lxqt-qtplugin is using private QPA API, which can, and does break BC
  even in point releases, so we need to hardcode libQt5Gui5 version
* Tue Nov 11 2014 andrea@opensuse.org
- Fixed license tag
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 andrea@opensuse.org
- removed unused build requires
* Tue May 13 2014 andrea@opensuse.org
- spec file clean up
* Mon May 12 2014 sfalken@opensuse.org
- removed fedora spec, split into subproject
  Del: lxqt-qtplugin-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-qtplugin-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-qtplugin-0.7.0.tar.xz
  Del:  _service
* Thu Apr  3 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-qtplugin.spec
  Add: lxqt-qtplugin.changes
